@@ -21,12 +21,12 @@
 #include <vector>
 #include <cstring> // strcmp
 
-namespace gdcm
+namespace gdcm_ns
 {
 
 /**
  * \brief Class to represent a Sequence Of Items
- * (value representation : SQ)
+ * \details (value representation : SQ)
  *  - a Value Representation for Data Elements that contains a sequence of Data Sets.
  *  - Sequence of Item allows for Nested Data Sets
  *
@@ -74,6 +74,9 @@ public:
 
   /// \brief Appends an Item to the already added ones
   void AddItem(Item const &item);
+    
+  /// \brief Appends an Item to the already added ones
+  Item & AddNewUndefinedLengthItem();
 
   /// Remove an Item as specified by its index, if index > size, false is returned
   /// Index starts at 1 not 0
@@ -252,7 +255,7 @@ public:
   ItemVector Items;
 };
 
-} // end namespace gdcm
+} // end namespace gdcm_ns
 
 #include "gdcmSequenceOfItems.txx"
 
