@@ -503,7 +503,9 @@ bool RLECodec::Code(DataElement const &in, DataElement &out)
         ptrdiff_t llength = rle_encode(outbuf, n, ptr + y*dims[0], partition / dims[1] /*image_len*/);
         if( llength < 0 )
           {
-          std::cerr << "RLE compressor error" << std::endl;
+          gdcmErrorMacro( "RLE compressor error" );
+          delete[] buffer;
+          delete[] bufferrgb;
           return false;
           }
         assert( llength );
@@ -557,7 +559,7 @@ bool RLECodec::Code(DataElement const &in, DataElement &out)
 // Endif
 // Endloop
 
-size_t RLECodec::DecodeFragment(Fragment const & frag, char *buffer, unsigned long llen)
+size_t RLECodec::DecodeFragment(Fragment const & frag, char *buffer, size_t llen)
 {
 
   std::stringstream is;
@@ -568,7 +570,7 @@ size_t RLECodec::DecodeFragment(Fragment const & frag, char *buffer, unsigned lo
   is.write(mybuffer, bv.GetLength());
   delete[] mybuffer;
   std::stringstream os;
-  SetLength( llen );
+  SetLength( (unsigned long)llen );
 #if !defined(NDEBUG)
   const unsigned int * const dimensions = this->GetDimensions();
   const PixelFormat & pf = this->GetPixelFormat();
@@ -636,7 +638,7 @@ bool RLECodec::Decode(DataElement const &in, DataElement &out)
       return false;
     }
     char *buffer = new char[len];
-    const unsigned long llen = len / nframes;
+    const std::size_t llen = len / nframes;
     // assert( GetNumberOfDimensions() == 2
     //      || GetDimension(2) == sf->GetNumberOfFragments() );
     bool corruption = false;
@@ -649,7 +651,7 @@ bool RLECodec::Decode(DataElement const &in, DataElement &out)
         gdcmDebugMacro( "RLE pb with frag: " << i );
         corruption = true;
       }
-      pos += llen;
+      pos += (unsigned long)llen;
       }
     if( !corruption )
       assert( pos == len );
