@@ -221,6 +221,15 @@ static const StreamOffset gdcmSelectedPrivateGroupOffsetDataFiles[] = {
 { "PHILIPS_Gyroscan-12-Jpeg_Extended_Process_2_4.dcm",1314},
 { "SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm", 1596 },
 { "00191113.dcm",536 },
+{ "JPEGNote_empty.dcm", 482 },
+{ "JPEGLS_CharLS_10742.dcm", 532 },
+{ "JPEGLosslessYBR_FULL_422.dcm", 534 },
+{ "JPEGNote_missing.dcm", 406 },
+{ "JPEGNote_bogus.dcm", 482 },
+{ "RLEDebianBug816607Orig.dcm", 534 },
+{ "IllegalGroup2ImplicitTS.dcm", 1088 },
+{ "JPEG_LS_InvalidEscapeSequence_COM_padding.dcm", 534 },
+{ "LengthOfItemLarger.dcm", 1044 },
 { "dicomdir_With_embedded_icons",7125212 },
 { "dicomdir_Pms_WithVisit_WithPrivate_WithStudyComponents",37218 },
 { "dicomdir_Acusson_WithPrivate_WithSR",3826 },
