@@ -223,6 +223,15 @@ static const StreamOffset gdcmSelectedTagsOffsetDataFiles[] = {
 { "ELSCINT1_PMSCT_RLE1_priv.dcm",298002 },
 { "00191113.dcm",922 },
 { "SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm", 48714 },
+{ "JPEGNote_empty.dcm", 704 },
+{ "JPEGLS_CharLS_10742.dcm", 748 },
+{ "JPEGLosslessYBR_FULL_422.dcm", 802 },
+{ "JPEGNote_missing.dcm", 596 },
+{ "JPEGNote_bogus.dcm", 722 },
+{ "RLEDebianBug816607Orig.dcm", 768 },
+{ "IllegalGroup2ImplicitTS.dcm", 2264 },
+{ "JPEG_LS_InvalidEscapeSequence_COM_padding.dcm", 752 },
+{ "LengthOfItemLarger.dcm", 12748 },
 { "dicomdir_Acusson_WithPrivate_WithSR",3826 },
 { "dicomdir_Pms_WithVisit_WithPrivate_WithStudyComponents",37218 },
 { "dicomdir_Pms_With_heavy_embedded_sequence",3003414 },
