@@ -24,15 +24,15 @@
 // GetValueAsSQ to solve that issue.
 static const char * const printmd5[][2] = {
 { "a19bffac370df32acbf6b4991d1cbafe" , "00191113.dcm" } ,
-{ "2e7d47d86dc6b541fccfa928c2ee05e8" , "012345.002.050.dcm" } ,
+{ "a5b2cb7d27bf0565296ae0391c07dd54" , "012345.002.050.dcm" } ,
 { "94f8c6ab090bdc11e61625bfc2dd39b7" , "05115014-mr-siemens-avanto-syngo-with-palette-icone.dcm" } ,
 { "20c11831c616eb121a405cd73de5cba2" , "05148044-mr-siemens-avanto-syngo.dcm" } ,
 { "ec10dcbf1b13ace8a6c0cc5b24c6c870" , "3E768EB7.dcm" } ,
 { "fde1da68a1707dcc687ddffd57e6b3c3" , "ACUSON-24-YBR_FULL-RLE-b.dcm" } ,
 { "a27c6628d6379783a3be223481d5cba4" , "ACUSON-24-YBR_FULL-RLE.dcm" } ,
 { "9f3aa114b955a812942f815b6b456eaf" , "ALOKA_SSD-8-MONO2-RLE-SQ.dcm" } ,
-{ "8b9bca2a22732c6165eba2fd3114d323" , "AMIInvalidPrivateDefinedLengthSQasUN.dcm" } ,
-{ "0df5a880b1973062f1e3850c27ee9568" , "BugGDCM2_UndefItemWrongVL.dcm" } ,
+{ "6c18a8fdd766660fbb475c05d0611634" , "AMIInvalidPrivateDefinedLengthSQasUN.dcm" } ,
+{ "9ddd03e5fd29f92bd02c3d3812b4e93e" , "BugGDCM2_UndefItemWrongVL.dcm" } ,
 { "6d2af85d2af299c223b684538d42d9e5" , "CR-MONO1-10-chest.dcm" } ,
 { "820d45cefd528e011921ea129bec9084" , "CT_16b_signed-UsedBits13.dcm" } ,
 { "fcf2ca019aa3138188edb18552983733" , "CT-MONO2-12-lomb-an2.acr" } ,
@@ -55,9 +55,9 @@ static const char * const printmd5[][2] = {
 { "b770b1ca257d7c1c885f69a5a1b58808" , "D_CLUNIE_MR2_JPLL.dcm" } ,
 { "da74aefef4e8ac49dbe1a4dd3b1dcb26" , "D_CLUNIE_MR2_JPLY.dcm" } ,
 { "023eb2a9ecbfd3c04bb148ec339865f0" , "D_CLUNIE_MR2_RLE.dcm" } ,
-{ "dca2414a88e95ef5ed59c088d20021b8" , "D_CLUNIE_MR3_JPLL.dcm" } ,
-{ "73c16bde7114f03b976009cba63c5f65" , "D_CLUNIE_MR3_JPLY.dcm" } ,
-{ "d1c358c3f79a5fc5592abe2b4b4a3571" , "D_CLUNIE_MR3_RLE.dcm" } ,
+{ "4ac28edcc53e3c5a2b14cee29ac4b350" , "D_CLUNIE_MR3_JPLL.dcm" } ,
+{ "1279c4aaacd1a058fc4b101cbfebec54" , "D_CLUNIE_MR3_JPLY.dcm" } ,
+{ "d6ca154c96d206995023f7349f6ca861" , "D_CLUNIE_MR3_RLE.dcm" } ,
 { "1646ec013060ef3f261849db705f80f3" , "D_CLUNIE_MR4_JPLL.dcm" } ,
 { "fbbfe4caab2179641bd0de5d8ccf79ae" , "D_CLUNIE_MR4_JPLY.dcm" } ,
 { "fafdb8499580e59c2f6d9047894272ea" , "D_CLUNIE_MR4_RLE.dcm" } ,
@@ -100,7 +100,7 @@ static const char * const printmd5[][2] = {
 { "3493bf0e698798529fde6ef488289879" , "ELSCINT1_JP2vsJ2K.dcm" } ,
 { "8f5581be656bd6f1ab6c9ec94f302284" , "ELSCINT1_LOSSLESS_RICE.dcm" } ,
 { "54f138a1aa6819ec1560a7ed344cde1a" , "ELSCINT1_PMSCT_RLE1.dcm" } ,
-{ "ff2965f3ca39bc0795df9850aa25467e" , "ExplicitVRforPublicElementsImplicitVRforShadowElements.dcm" } ,
+{ "d576bf8e8b2ca71fd543d29698807e85" , "ExplicitVRforPublicElementsImplicitVRforShadowElements.dcm" } ,
 { "3199cd21166043d619209d7a2073fb56" , "fffc0000UN.dcm" } ,
 { "9b426b02521cbc2f3ee25ab383ca835e" , "FUJI-10-MONO1-ACR_NEMA_2.dcm" } ,
 { "2aba3dacd00a0bc14a06e2d7142b916a" , "gdcm-ACR-LibIDO.acr" } ,
@@ -116,10 +116,10 @@ static const char * const printmd5[][2] = {
 { "9e126a24f81534e1cd653f16739a6192" , "GE_DLX-8-MONO2-Multiframe.dcm" } ,
 { "6b66f8c38fe96db805e7dedd9a997811" , "GE_DLX-8-MONO2-Multiframe-Jpeg_Lossless.dcm" } ,
 { "61ca6c5115e6f74565f6f2ca06647444" , "GE_DLX-8-MONO2-PrivateSyntax.dcm" } ,
-{ "459247061fb21a9cbf0bbb359a0af160" , "GE_GENESIS-16-MONO2-Uncompressed-UnusualVR.dcm" } ,
+{ "7920bf7f1269ba54dd8d0e0d375dc4b9" , "GE_GENESIS-16-MONO2-Uncompressed-UnusualVR.dcm" } ,
 { "8d398fce426d3a248d8c3f7582e3751d" , "GE_GENESIS-16-MONO2-WrongLengthItem.dcm" } ,
 { "bb5d500a0391a399b035968496b6fd5d" , "GE_LOGIQBook-8-RGB-HugePreview.dcm" } ,
-{ "7aad71b9c70060c0a39a73b2f489d68f" , "GE_MR_0025xx1bProtocolDataBlock.dcm" } ,
+{ "1ad963ca1e91932bb1ac58f3dddd981f" , "GE_MR_0025xx1bProtocolDataBlock.dcm" } ,
 { "d5efa34d8091e1ad04683eefb41f33c7" , "GE_RHAPSODE-16-MONO2-JPEG-Fragments.dcm" } ,
 { "d41d8cd98f00b204e9800998ecf8427e" , "IM-0001-0066.dcm" } ,
 { "cd085d783924d8a7fa2270ff40c6dc3e" , "ITK_GDCM124_MultiframeSecondaryCaptureInvalid.dcm" } ,
@@ -150,17 +150,17 @@ static const char * const printmd5[][2] = {
 { "497d6ea45b8f3f7f6a3bf8125dcc43b1" , "MR16BitsAllocated_8BitsStored.dcm" } ,
 { "5b23ccf10ad6358b253a7ec185deb2a9" , "MR-Brucker-CineTagging-NonSquarePixels.dcm" } ,
 { "31246836410a24124acf6bea5a36a942" , "MR_ELSCINT1_00e1_1042_SQ_feff_00e0_Item.dcm" } ,
-{ "285433f0db3a7aae20a4734644fc959d" , "MR_GE_with_Private_Compressed_Icon_0009_1110.dcm" } ,
+{ "7a61574251f8788a11cfe06ddc109bd9" , "MR_GE_with_Private_Compressed_Icon_0009_1110.dcm" } ,
 { "8419613dfb8d4b190ef8a988f8927bce" , "MR-MONO2-12-an2.acr" } ,
 { "b4058b67ec1eb3d3d3acde27d51eb24a" , "MR-MONO2-12-angio-an1.acr" } ,
 { "f782f6ea25928310bd69c3ca5c6a97d2" , "MR-MONO2-12-shoulder.dcm" } ,
 { "7f6bccb00b34a7d277eacaffd2bb0362" , "MR-MONO2-16-head.dcm" } ,
 { "9bd4d79cc59c66b19c21577e12cd6226" , "MR-MONO2-8-16x-heart.dcm" } ,
 { "cd623ac04602182dc66adb505c516341" , "MR_Philips-Intera_BreaksNOSHADOW.dcm" } ,
-{ "f295d87a398e0bcd96c5dfa20d96a419" , "MR_Philips_Intera_No_PrivateSequenceImplicitVR.dcm" } ,
-{ "af3c49db53cfb30aa438e7369dba117b" , "MR_Philips_Intera_PrivateSequenceExplicitVR_in_SQ_2001_e05f_item_wrong_lgt_use_NOSHADOWSEQ.dcm" } ,
-{ "d7019c1822870140965fa3345b53886c" , "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm" } ,
-{ "69ccce1a3bb1c481d90a1df109acf3b7" , "MR_Philips_Intera_SwitchIndianess_noLgtSQItem_in_trueLgtSeq.dcm" } ,
+{ "ced145431248f1e00e9bdc23b0c61674" , "MR_Philips_Intera_No_PrivateSequenceImplicitVR.dcm" } ,
+{ "8eab7fcf9c53d06968dde33f6b3a8918" , "MR_Philips_Intera_PrivateSequenceExplicitVR_in_SQ_2001_e05f_item_wrong_lgt_use_NOSHADOWSEQ.dcm" } ,
+{ "3d24233b19788d349f64b7b267723186" , "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm" } ,
+{ "1693399bc1edb7cdc494095a27201eab" , "MR_Philips_Intera_SwitchIndianess_noLgtSQItem_in_trueLgtSeq.dcm" } ,
 { "5797c9dfe94e4a4bccfbf81ab0aaa957" , "MR-SIEMENS-DICOM-WithOverlays.dcm" } ,
 { "df28467760104edc923d0625a0e2a778" , "MR-SIEMENS-DICOM-WithOverlays-extracted-overlays.dcm" } ,
 { "bf324a1c91d3a09d9136f54f5910e570" , "MR_SIEMENS_forceLoad29-1010_29-1020.dcm" } ,
@@ -171,12 +171,12 @@ static const char * const printmd5[][2] = {
 { "7f4cddc9a88f8c5147b89f769eb1cae7" , "OT-PAL-8-face.dcm" } ,
 { "5fce2728bd9457d4fc1224a374829e2f" , "PET-cardio-Multiframe-Papyrus.dcm" } ,
 { "071b840050588d14fde61646e058e1c6" , "PHILIPS_Brilliance_ExtraBytesInOverlay.dcm" } ,
-{ "244e8beb3151f9a26dd8c0650a4adede" , "PHILIPS_GDCM12xBug2.dcm" } ,
-{ "3d7cc6eaf1c2f065290c50473bc8001a" , "PHILIPS_GDCM12xBug.dcm" } ,
+{ "a7eb66c4f66784ad456d060b7123ea15" , "PHILIPS_GDCM12xBug2.dcm" } ,
+{ "48203ef1f45cb1f7f919de53062db5d0" , "PHILIPS_GDCM12xBug.dcm" } ,
 { "c38ad661c6a14f8bd88b304755e7ba7b" , "PHILIPS_Gyroscan-12-Jpeg_Extended_Process_2_4.dcm" } ,
 { "e0a690636c608f312ca550908d4b551f" , "PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm" } ,
 { "03d88060c3bd820b96840599c0099470" , "PHILIPS_Gyroscan-8-MONO2-Odd_Sequence.dcm" } ,
-{ "1caa6b627fa7dc0995efc2a36765055e" , "PHILIPS_Intera-16-MONO2-Uncompress.dcm" } ,
+{ "1f198bdb09f5e52dc3f9ad1dfced8a4d" , "PHILIPS_Intera-16-MONO2-Uncompress.dcm" } ,
 { "4f34474ed72e6a5960fc4691e588f8e0" , "PICKER-16-MONO2-Nested_icon.dcm" } ,
 { "629da04611e097e2cc532d6fe5e6454d" , "PICKER-16-MONO2-No_DicomV3_Preamble.dcm" } ,
 { "3aaca1826b4a4deb9e41ebf2af4fa6b2" , "PrivateGEImplicitVRBigEndianTransferSyntax16Bits.dcm" } ,
@@ -206,9 +206,9 @@ static const char * const printmd5[][2] = {
 { "cbd59e416dd82dc14df251ea6fccb55b" , "test.acr" } ,
 { "0c2c475f6d21ae0aeadbf16565dcdbc4" , "TG18-CH-2k-01.dcm" } ,
 { "e8cc7ed19eedf9bed9ab60683f3dbfa1" , "THERALYS-12-MONO2-Uncompressed-Even_Length_Tag.dcm" } ,
-{ "463888b21317e5816584541c7243e124" , "TheralysGDCM120Bug.dcm" } ,
+{ "aa708d3b15e451c8367e7909257d9346" , "TheralysGDCM120Bug.dcm" } ,
 { "e8819809884c214fe78ee2b227417e5c" , "TOSHIBA_MRT150-16-MONO2-ACR_NEMA_2.dcm" } ,
-{ "9fcf7924fef1b48977b8c4b9a84caa87" , "undefined_length_un_vr.dcm" } ,
+{ "fafc22cde1c9092cb188982ecee8da9b" , "undefined_length_un_vr.dcm" } ,
 { "787ca80c8dd1aa619d5f85610862380b" , "US-GE-4AICL142.dcm" } ,
 { "f1e9c893391e1d458cffa2a1e0904160" , "US-IRAD-NoPreambleStartWith0003.dcm" } ,
 { "d1d9be67c9d066fabc8e1c4ae124f9a0" , "US-IRAD-NoPreambleStartWith0005.dcm" } ,
@@ -221,7 +221,7 @@ static const char * const printmd5[][2] = {
 { "d2cb6962750eb8f92c480e6cc2f4d104" , "GDCMJ2K_TextGBR.dcm" },
 { "2e039bbc7520f809963e051ff5144ccf" , "UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" },
 { "0a90894370ba84dbe31acd1290ff9999" , "NM_Kakadu44_SOTmarkerincons.dcm" },
-{ "bcadb7b0f72d2ea3d4e910b885f07087" , "PhilipsInteraSeqTermInvLen.dcm" },
+{ "fdd8a53915712a924ac74c26ec4d1051" , "PhilipsInteraSeqTermInvLen.dcm" },
 { "2940bd46f097f79012d24f47504c3c8c" , "TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
 { "696917fea41e83b9980bad82b609162c" , "TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
 { "7ef3da46c43e51cfe2eb82e4d23dd623" , "TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
@@ -231,6 +231,14 @@ static const char * const printmd5[][2] = {
 { "4be7f56f11ce6090b7139879c4fdc71f" , "SC16BitsAllocated_8BitsStoredJPEG.dcm" },
 { "1060ff4eb8731d4b2152db83fed2eedd" , "SC16BitsAllocated_8BitsStoredJ2K.dcm" },
 { "7dc0a8ffffc8fb441dbd4129111eaf8b" , "SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm" },
+{ "41d1baead629d878d09d6c1037faf47a" , "JPEGNote_empty.dcm" },
+{ "3cb9917c468226c265ef637aac5f4b61" , "JPEGLS_CharLS_10742.dcm" },
+{ "8381875d83ce321955a064e40d047dde" , "JPEGLosslessYBR_FULL_422.dcm" },
+{ "67f7b36ad6e54889b4a2581baa41afdf" , "JPEGNote_missing.dcm" },
+{ "807bf2aef3bc1885217c8a12d2d2bc19" , "JPEGNote_bogus.dcm" },
+{ "669cc0e807673ebe57124739a1874f35" , "RLEDebianBug816607Orig.dcm" },
+{ "1daa9bb53a8ce090041472f528248686" , "IllegalGroup2ImplicitTS.dcm" },
+
 
 { 0 ,0 }
 };
