@@ -51,7 +51,11 @@
 #include "gdcmIPPSorter.h"
 
 #ifndef vtkFloatingPointType
+#if VTK_MAJOR_VERSION < 6
 #define vtkFloatingPointType float
+#else
+#define vtkFloatingPointType double
+#endif
 #endif
 
 //----------------------------------------------------------------------------
