@@ -25,7 +25,11 @@
 #include "gdcmImageReader.h"
 
 #ifndef vtkFloatingPointType
+#if VTK_MAJOR_VERSION < 6
 #define vtkFloatingPointType float
+#else
+#define vtkFloatingPointType double
+#endif
 #endif
 
 int TestvtkGDCMImageWrite(const char *filename, bool verbose = false)
