@@ -29,7 +29,11 @@
 #include <iostream>
 
 #ifndef vtkFloatingPointType
+#if VTK_MAJOR_VERSION < 6
 #define vtkFloatingPointType float
+#else
+#define vtkFloatingPointType double
+#endif
 #endif
 
 int TestvtkGDCMImageWrite2(const char *filename, bool verbose = false)
