@@ -103,7 +103,11 @@ class VTK_EXPORT vtkGDCMImageReader : public vtkMedicalImageReader2
 {
 public:
   static vtkGDCMImageReader *New();
+#if VTK_MAJOR_VERSION < 6
   vtkTypeRevisionMacro(vtkGDCMImageReader,vtkMedicalImageReader2);
+#else
+  vtkTypeMacro(vtkGDCMImageReader,vtkMedicalImageReader2);
+#endif
   virtual void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description: is the given file name a DICOM file containing an image ?
